cosinnus.templatetags package
=============================

Submodules
----------

cosinnus.templatetags.cosinnus_tags module
------------------------------------------

.. automodule:: cosinnus.templatetags.cosinnus_tags
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.templatetags
    :members:
    :undoc-members:
    :show-inheritance:
